@@ -49,6 +49,8 @@ struct _GcalManagerClass
   void (*source_activated)  (GcalManager *manager, ESource *source, gboolean active);
   void (*source_added)  (GcalManager *manager, ESource *source, gboolean enabled);
   void (*source_removed)  (GcalManager *manager, ESource *source);
+  void (*load_completed)  (GcalManager *manager);
+  void (*query_completed) (GcalManager *manager);
 };
 
 typedef struct
@@ -69,6 +71,21 @@ ESource*       gcal_manager_get_default_source      (GcalManager        *manager
 
 icaltimezone*  gcal_manager_get_system_timezone     (GcalManager        *manager);
 
+void           gcal_manager_setup_shell_search      (GcalManager             *manager,
+                                                     ECalDataModelSubscriber *subscriber);
+
+void           gcal_manager_set_shell_search_query  (GcalManager        *manager,
+                                                     const gchar        *query);
+
+void           gcal_manager_set_shell_search_subscriber (GcalManager             *manager,
+                                                         ECalDataModelSubscriber *subscriber,
+                                                         time_t                   range_start,
+                                                         time_t                   range_end);
+
+gboolean       gcal_manager_shell_search_done       (GcalManager        *manager);
+
+GList*         gcal_manager_get_shell_search_events (GcalManager        *manager);
+
 void           gcal_manager_set_subscriber          (GcalManager        *manager,
                                                      ECalDataModelSubscriber *subscriber,
                                                      time_t              range_start,
@@ -93,6 +110,9 @@ void           gcal_manager_enable_source           (GcalManager        *manager
 void           gcal_manager_disable_source          (GcalManager        *manager,
                                                      ESource            *source);
 
+gboolean       gcal_manager_source_enabled          (GcalManager        *manager,
+                                                     ESource            *source);
+
 void           gcal_manager_refresh                 (GcalManager        *manager);
 
 gboolean       gcal_manager_is_client_writable      (GcalManager        *manager,
@@ -123,6 +143,11 @@ GList*         gcal_manager_get_events              (GcalManager        *manager
                                                      icaltimetype       *range_start,
                                                      icaltimetype       *range_end);
 
+gboolean       gcal_manager_load_completed          (GcalManager        *manager);
+
+GcalEventData* gcal_manager_get_event_from_shell_search (GcalManager        *manager,
+                                                         const gchar        *uuid);
+
 G_END_DECLS
 
 #endif /* __GCAL_MANAGER_H__ */
