@@ -168,10 +168,6 @@ static void           place_new_event_widget             (GcalWindow          *w
 static void           close_new_event_widget             (GtkButton           *button,
                                                           gpointer             user_data);
 
-static void           new_event_entry_text_changed       (GObject             *object,
-                                                          GParamSpec          *pspec,
-                                                          gpointer             user_data);
-
 static void           create_notification                (GcalWindow          *window,
                                                           gchar               *message,
                                                           gchar               *button_label);
@@ -636,10 +632,7 @@ prepare_new_event_widget (GcalWindow *window)
 
   /* setting title */
   tm_date = icaltimetype_to_tm (priv->event_creation_data->start_date);
-  /* Translators:
-   * this is the format string for representing a date consisting of a month name
-   * and a date of month. */
-  e_utf8_strftime_fix_am_pm (start, 64, C_("event date format", "%B %d"), &tm_date);
+  e_utf8_strftime_fix_am_pm (start, 64, "%B %d", &tm_date);
   title_date = g_strdup_printf (_("New Event on %s"), start);
 
   gtk_label_set_text (GTK_LABEL (priv->new_event_title_label),
@@ -680,34 +673,6 @@ close_new_event_widget (GtkButton *button,
   set_new_event_mode (GCAL_WINDOW (user_data), FALSE);
 }
 
-static void
-new_event_entry_text_changed (GObject    *object,
-                              GParamSpec *pspec,
-                              gpointer    user_data)
-{
-  GcalWindowPrivate *priv;
-  static gboolean blocked = TRUE;
-  gint length;
-
-  g_return_if_fail (user_data);
-  priv = gcal_window_get_instance_private (GCAL_WINDOW (object));
-
-  length = g_utf8_strlen (gtk_entry_get_text (GTK_ENTRY (user_data)), -1);
-
-  gtk_widget_set_sensitive (priv->new_event_create_button, length > 0);
-
-  if (length > 0 && blocked)
-    {
-      g_signal_handlers_unblock_by_func (user_data, create_event, object);
-      blocked = FALSE;
-    }
-  else if (length < 1 && !blocked)
-    {
-      g_signal_handlers_block_by_func (user_data, create_event, object);
-      blocked = TRUE;
-    }
-}
-
 /**
  * create_notification: Internal method for creating a notification
  * @window:
@@ -1327,7 +1292,6 @@ gcal_window_class_init(GcalWindowClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, create_event_detailed_cb);
   gtk_widget_class_bind_template_callback (widget_class, show_new_event_widget);
   gtk_widget_class_bind_template_callback (widget_class, close_new_event_widget);
-  gtk_widget_class_bind_template_callback (widget_class, new_event_entry_text_changed);
   gtk_widget_class_bind_template_callback (widget_class, event_activated);
 
   /* Syncronization related */
@@ -1371,8 +1335,6 @@ gcal_window_constructed (GObject *object)
   g_free (clock_format);
   g_object_unref (helper_settings);
 
-  // Prevents nameless events' creation
-  g_signal_handlers_block_by_func (priv->new_event_what_entry, create_event, object);
 
   /* header_bar: menu */
   builder = gtk_builder_new ();
@@ -1605,8 +1567,10 @@ gcal_window_new_event (GcalWindow *window)
   /* 1st and 2nd steps */
   set_new_event_mode (window, TRUE);
 
-  start_date = gcal_dup_icaltime (priv->active_date);
-  end_date = gcal_dup_icaltime (priv->active_date);
+  start_date = gcal_dup_icaltime (priv->current_date);
+  start_date->is_date = 1;
+  end_date = gcal_dup_icaltime (priv->current_date);
+  end_date->is_date = 1;
 
   /* adjusting dates according to the actual view */
   switch (priv->active_view)
@@ -1616,14 +1580,10 @@ gcal_window_new_event (GcalWindow *window)
       end_date->hour += 1;
       *end_date = icaltime_normalize (*end_date);
       break;
-    case GCAL_WINDOW_VIEW_YEAR:
-      start_date->day = 1;
-      end_date->day = icaltime_days_in_month (end_date->month, end_date->year);
-      break;
     case GCAL_WINDOW_VIEW_MONTH:
-      start_date->is_date = 1;
-      end_date->is_date = 1;
+    case GCAL_WINDOW_VIEW_YEAR:
       end_date->day += 1;
+      end_date->is_date = 1;
       *end_date = icaltime_normalize (*end_date);
       break;
     case GCAL_WINDOW_VIEW_LIST:
